/***********************************************************************
 * Module:  IXmPlayer.aidl
 * Author:  chadwii
 * Purpose: Defines the Interface IXmPlayer
 ***********************************************************************/
package com.ximalaya.ting.android.opensdk.player.service;

import com.ximalaya.ting.android.opensdk.player.service.IXmDataCallback;
import com.ximalaya.ting.android.opensdk.player.service.IXmPlayerEventDispatcher;
import com.ximalaya.ting.android.opensdk.player.service.IXmAdsEventDispatcher;
import com.ximalaya.ting.android.opensdk.player.service.IXmGetDownloadPlayPathCallback;
import com.ximalaya.ting.android.opensdk.model.PlayableModel;
import com.ximalaya.ting.android.opensdk.model.track.Track;
import com.ximalaya.ting.android.opensdk.model.live.radio.Radio;
import com.ximalaya.ting.android.opensdk.model.live.program.Program;
import com.ximalaya.ting.android.opensdk.model.live.schedule.Schedule;
import com.ximalaya.ting.android.opensdk.model.category.CategoryModel;
import com.ximalaya.ting.android.opensdk.player.service.IXmCustomDataCallBack;
import com.ximalaya.ting.android.opensdk.player.service.IXmMainDataSupportDataCallback;
import com.ximalaya.ting.android.opensdk.model.xdcs.CdnConfigModel;
import com.ximalaya.ting.android.opensdk.model.statistic.RecordModel;

interface IXmPlayer {
   
   //waring ：请不要在以下加入或者减少任何方法
   //*******************************************播放器所用，请不要增加和删除任何以下方法***************************************
   void setProxy(String host, int port,String authorization ,in Map header);
   boolean playPre();
   boolean playNext();
   boolean play(int index);
   boolean setPlayIndex(int index);
   boolean startPlay();
   boolean pausePlay();
   boolean stopPlay();
   boolean seekTo(int ms);
   boolean isOnlineSource();
   boolean hasPreSound();
   boolean hasNextSound();
   int getPlayerStatus();
   int getCurrIndex();
   int getDuration();
   int getPlayCurrPosition();
   boolean isPlaying();
   boolean isAdsActive();
   void updateTrackDownloadUrlInPlayList(inout Track track);
   boolean updateTrackInPlayList(inout Track track);
   Track getTrack(int index);
   Radio getRadio();
   int getPlaySourceType();
   void setPlayMode(String mode);
   String getPlayMode();
   void setPageSize(int pageSize);
   void setPlayList(in Map param, in List<Track> list);
   // 因为IPC通信机制限制只能传递1M所以setPlayList暂时只能传递100个超过的话就将其拆分循环插入 ,执行这个函数之前一定要先执行setPlayList
   void addPlayList(in List<Track> list);
   boolean playRadio(in Radio radio);
   // position表示第几次请求 ,position从0开始计算
   List<Track> getPlayList(in int position);
   Map getParam();
   int getPlayListSize();
   void clearPlayCache();
   void setNotification(int id, in Notification notification);
   void setAppSecret(String secret);
   void registePlayerListener(IXmPlayerEventDispatcher l);
   void unregistePlayerListener(IXmPlayerEventDispatcher l);
   void registeAdsListener(IXmAdsEventDispatcher l);
   void unregisteAdsListener(IXmAdsEventDispatcher l);
   void setDownloadPlayPathCallback(IXmGetDownloadPlayPathCallback l);
   void getNextPlayList();
   void getPrePlayList();
   void setPlayListChangeListener(IXmDataCallback l);
   boolean permutePlayList();
   boolean getPositiveSeq();
   String getCurPlayUrl(); 
   //*******************************************播放器所用，请不要增加和删除任何以上方法***************************************
   
   
   //*******************************************第三方所用***************************************
   void init(String appsecret, String appkey, String packid);
   void registeCustomDataCallBack(IXmCustomDataCallBack l);
   void unregisteCustomDataCallBack(IXmCustomDataCallBack l);
   void setPlayModel(String modelName ,int categoryId ,long key);
   void getSourseLists(String query,int categoryId, int page ,int count ,int type ,long key);
   void browseAlbums(long albumId ,int page ,int count ,long key);
   void setPlayByTrack(String track ,long key);	
   void setPlayByAlbumTracks(String CommonTrackList, int position ,long key);
   void setCategoryId(int categoryId ,long key);
   void getCategoryModelList(long key);
   void getHotContent(boolean isTrack ,int page ,int count ,long key);
   void getTrackListByLastTrack(long albumId ,long trackId ,int pageCount ,long key);
   // 主app的aidl通信
   void registeMainDataSupportCallBack(IXmMainDataSupportDataCallback l);
   void unregisteMainDataSupportCallBack(IXmMainDataSupportDataCallback l);
   void getUserInfo(long key);
   void getMyCollect(int page ,long key);
   void getAlbumInfo(long albumId ,int page ,long randomkey);
   void getRank(String type ,String key ,int page,long randomkey);
   void getMainHotContent(int type ,int page ,long randomkey);
   int getDefultPageSize();
   
   // speechcontroler 的方法
   void getAlbumByCategoryId(long categoryid, int page, int count ,long key);
   
   // MainDataSupport 智能硬件 获得硬件插件的配置信息
   void getParseDeviceInfo(long randomkey);
   void setDLNAState(boolean isDLNAState);
   boolean isDLNAState();
   void needContinuePlay(boolean flag);
   void setRecordModel(inout RecordModel model);
   //*******************************************第三方所用***************************************

   
   //*******************************************请在以下加入非第三方使用的aidl接口***************************************
   
   void setVolume(float leftVolume, float rightVolume); 
   void setPlayStatisticClassName(String className);
   void setAdsDataHandlerClassName(String className);
   void setPlayCdnConfigureModel(in CdnConfigModel cdnConfigure);
   void resetPlayList();
   void removeListByIndex(int index);
   String getHistoryPos(String historyIds);
   String getLastPlayTrackInAlbum(String albumId);
   // 设置播放进程的请求环境(开发环境environmentId=2，测试环境environmentId=4，线上环境environmentId=1)
   void setPlayerProcessRequestEnvironment(int environment);
   
   //*******************************************请在以上加入非第三方使用的aidl接口***************************************
   
}